@@ -36,6 +36,10 @@ class jArticles(MCCore):
             Log.e("Failed to Connect to DB.", error=e)
             return False
 
+    def article_url_exists(self, potentialUrl):
+        url_query = Q.BASE(F.URL, potentialUrl)
+        return self.base_query(kwargs=url_query)
+
     def article_exists(self, article):
         Log.i(f"Checking if Article already exists in Database...")
         q_date = self.get_arg(F.PUBLISHED_DATE, article)
@@ -82,7 +86,7 @@ class jArticles(MCCore):
         else:
             q_id = { "_id": _id }
         Log.d(f"Beginning Article Queue. ID=[ {_id} ]")
-        self.update_record(q_id, single_article)
+        self.update_record(q_id, single_article )
         Log.d(f"Finished Article Queue.")
 
     def replace_articles(self, list_of_articles):
